<?php
/*
Plugin Name: All In One Schema.org Rich Snippets
Plugin URI: http://www.brainstormforce.com
Description: The All in One Rich Snippets gives the power to the blog author to control the rich snippets to be shown in the search results by the search engines.
Version: 1.0.1
Author: Brainstorm Force
Author URI: http://www.brainstormforce.com
License: GPL2
*/
?>
<?php
/*  Copyright 2013 All in One Rich Snippets (email : nitiny@brainstormforce.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
?>
<?php
if ( !class_exists( "RichSnippets" ) )
{
	class RichSnippets
	{
		function __construct() // Constructor
		{
			register_activation_hook( __FILE__, array($this, 'run_on_activate') );

			add_action( 'admin_head', array( $this, 'star_icons') );
			// Add Admin Menu
			add_action('admin_menu', array( $this, 'register_custom_menu_page') );
			
			add_action( 'admin_init', array( $this, 'set_styles' ));
			
			add_action( 'wp_head', array($this, 'frontend_style') );
			
			add_filter('plugins_loaded', array( $this, 'rich_snippet_translation'));
			
			add_action( 'admin_enqueue_scripts', array( $this, 'post_enqueue') );
			
			add_action( 'admin_enqueue_scripts', array( $this, 'post_new_enqueue') );

			$plugin = plugin_basename(__FILE__); 
			add_filter("plugin_action_links_$plugin", array( $this,'bsf_settings_link') );		
		}
		
		function frontend_style() {
			wp_register_style( 'bsf_style', plugins_url('/css/style.css', __FILE__) );
			wp_enqueue_style('bsf_style');
		}
		function register_custom_menu_page() 
		{
			require_once('admin/index.php');
			$page = add_menu_page('All in One Rich Snippets Dashboard', 'Rich Snippets', 'administrator', 'rich_snippet_dashboard', 'rich_snippet_dashboard', 'div');
			//Call the function to print the stylesheets and javascripts in only this plugins admin area
			add_action( 'admin_print_styles-' . $page, 'bsf_admin_styles' ); 
		}
		// Add settings link on plugin page
		function bsf_settings_link($links) { 
		  $settings_link = '<a href="admin.php?page=rich_snippet_dashboard">Settings</a>'; 
		  array_unshift($links, $settings_link); 
		  return $links; 
		}
		function run_on_activate()
		{
			wp_enqueue_style('wp-pointer');
			wp_enqueue_script('wp-pointer');
			add_action('admin_print_footer_scripts',  array( $this,'custom_print_footer_scripts') );
		}

		function custom_print_footer_scripts(){
			$pointer_content = '<h3>Rich Snippets Installed !</h3>';
			$pointer_content .= '<p>Check out this panel to know more about "All in One Schema.org Rich Snippets".</p>';
		?>
		   <script type="text/javascript">
		   //<![CDATA[
		   jQuery(document).ready( function(jQuery) {
			jQuery('#all-in-one-rich-snippets').pointer({
				content: '<?php echo $pointer_content; ?>',
				position: 'top',
				close: function() {
					// This function is fired when you click the close button
				}
			  }).pointer('open');
		   });
		   //]]>
		   </script>
		<?php
		}

		//print the star rating style on post edit page
		function post_enqueue($hook) {
			if( 'post.php' != $hook )
				return;
		//	wp_enqueue_script( 'bsf_jquery' );
			wp_enqueue_script( 'jquery' );		
			wp_enqueue_script( 'bsf_jquery_star' );
			wp_enqueue_script( 'bsf_toggle' );		
			wp_enqueue_style( 'star_style' );
		}
		function post_new_enqueue($hook) {
			if('post-new.php' != $hook )
				return;
		//	wp_enqueue_script( 'bsf_jquery' );
			wp_enqueue_script( 'jquery' );		
			wp_enqueue_script( 'bsf_jquery_star' );
			wp_enqueue_script( 'bsf_toggle' );		
			wp_enqueue_style( 'star_style' );
		}

		//Initialize the metabox class
		function wp_initialize_bsf_meta_boxes() {
			if ( ! class_exists( 'bsf_Meta_Box' ) )
				require_once(plugin_dir_path( __FILE__ ) . 'init.php');
		}

		function set_styles() {
			wp_register_style( 'star_style', plugins_url('/css/jquery.rating.css', __FILE__) );
			wp_register_script( 'bsf_jquery_ui', plugins_url('/js/jquery-ui.js', __FILE__) ); 
			wp_register_script( 'bsf_jquery_star', plugins_url('/js/jquery.rating.min.js', __FILE__) ); 
			wp_register_script( 'bsf_toggle', plugins_url('/js/toggle.js', __FILE__) ); 
		}


		// Define icon styles for the custom post type
		function star_icons() {
		?>
		<style>
			#toplevel_page_rich_snippet_dashboard .wp-menu-image {
				background: url(<?php echo plugins_url('/images/star.png',__FILE__); ?>) no-repeat !important;
			}
			#toplevel_page_rich_snippet_dashboard:hover .wp-menu-image, #toplevel_page_rich_snippet_dashboard.wp-has-current-submenu .wp-menu-image {
				background: url(<?php echo plugins_url('/images/star.png',__FILE__); ?>) no-repeat 0 -32px !important;
			}
			#toplevel_page_rich_snippet_dashboard .current .wp-menu-image, #toplevel_page_rich_snippet_dashboard.wp-has-current-submenu .wp-menu-image {
				background: url(<?php echo plugins_url('/images/star.png',__FILE__); ?>) no-repeat 0 -32px !important;
			}
			#star-icons-32.icon32 {background: url(<?php echo plugins_url('/images/gray-32.png',__FILE__); ?>) no-repeat;}
		</style>
		
		<?php }

		/* Translation */
		function rich_snippet_translation()
		{
			// Load Translation File
			load_plugin_textdomain('rich-snippets', false, basename( dirname( __FILE__ ) ) . '/lang/' );
		}
	}
}

	require_once('functions.php');

	add_filter( 'bsf_meta_boxes', 'bsf_metaboxes' );

// Instantiating the Class
if (class_exists("RichSnippets")) {
	$RichSnippets= new RichSnippets();
}

?>